PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Util/Util.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Namespaces | Functions
Util.hpp File Reference

Go to the source code of this file.

## Namespaces
namespace | util

## Functions
bool | util::lexiconumeric_compare (const std::string &, const std::string &)
std::string | util::loadFile (const std::string &filePath)
std::string | util::loadFile (const std::string_view filePath)
std::string | util::tolower (const std::string &)
bool | util::is1TrueYesOrPlus (const char *)
bool | util::is1TrueYesOrPlus (const std::string &s)